// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-A4BMJM77.js";

// packages/core/src/tools/tool-names.ts
init_esbuild_shims();
var ToolNames = {
  EDIT: "edit",
  WRITE_FILE: "write_file",
  READ_FILE: "read_file",
  GREP: "grep_search",
  GLOB: "glob",
  SHELL: "run_shell_command",
  TODO_WRITE: "todo_write",
  MEMORY: "save_memory",
  AGENT: "agent",
  SKILL: "skill",
  EXIT_PLAN_MODE: "exit_plan_mode",
  WEB_FETCH: "web_fetch",
  LS: "list_directory",
  LSP: "lsp",
  ASK_USER_QUESTION: "ask_user_question",
  CRON_CREATE: "cron_create",
  CRON_LIST: "cron_list",
  CRON_DELETE: "cron_delete",
  TASK_STOP: "task_stop",
  SEND_MESSAGE: "send_message",
  STRUCTURED_OUTPUT: "structured_output",
  MONITOR: "monitor",
  NOTEBOOK_EDIT: "notebook_edit",
  TOOL_SEARCH: "tool_search",
  ENTER_WORKTREE: "enter_worktree",
  EXIT_WORKTREE: "exit_worktree",
  // Computer Use tools — built-in but backed by an upstream MCP server.
  // All deferred; revealed only when the user-initiated request triggers
  // a computer-use action. See packages/core/src/tools/computer-use/.
  COMPUTER_USE_LIST_APPS: "computer_use__list_apps",
  COMPUTER_USE_GET_APP_STATE: "computer_use__get_app_state",
  COMPUTER_USE_CLICK: "computer_use__click",
  COMPUTER_USE_PERFORM_SECONDARY_ACTION: "computer_use__perform_secondary_action",
  COMPUTER_USE_SCROLL: "computer_use__scroll",
  COMPUTER_USE_DRAG: "computer_use__drag",
  COMPUTER_USE_TYPE_TEXT: "computer_use__type_text",
  COMPUTER_USE_PRESS_KEY: "computer_use__press_key",
  COMPUTER_USE_SET_VALUE: "computer_use__set_value"
};
var ToolDisplayNames = {
  EDIT: "Edit",
  WRITE_FILE: "WriteFile",
  READ_FILE: "ReadFile",
  GREP: "Grep",
  GLOB: "Glob",
  SHELL: "Shell",
  TODO_WRITE: "TodoWrite",
  MEMORY: "SaveMemory",
  AGENT: "Agent",
  SKILL: "Skill",
  EXIT_PLAN_MODE: "ExitPlanMode",
  WEB_FETCH: "WebFetch",
  LS: "ListFiles",
  LSP: "Lsp",
  ASK_USER_QUESTION: "AskUserQuestion",
  CRON_CREATE: "CronCreate",
  CRON_LIST: "CronList",
  CRON_DELETE: "CronDelete",
  TASK_STOP: "TaskStop",
  SEND_MESSAGE: "SendMessage",
  STRUCTURED_OUTPUT: "StructuredOutput",
  MONITOR: "Monitor",
  NOTEBOOK_EDIT: "NotebookEdit",
  TOOL_SEARCH: "ToolSearch",
  ENTER_WORKTREE: "EnterWorktree",
  EXIT_WORKTREE: "ExitWorktree",
  COMPUTER_USE_LIST_APPS: "computer_use__list_apps",
  COMPUTER_USE_GET_APP_STATE: "computer_use__get_app_state",
  COMPUTER_USE_CLICK: "computer_use__click",
  COMPUTER_USE_PERFORM_SECONDARY_ACTION: "computer_use__perform_secondary_action",
  COMPUTER_USE_SCROLL: "computer_use__scroll",
  COMPUTER_USE_DRAG: "computer_use__drag",
  COMPUTER_USE_TYPE_TEXT: "computer_use__type_text",
  COMPUTER_USE_PRESS_KEY: "computer_use__press_key",
  COMPUTER_USE_SET_VALUE: "computer_use__set_value"
};
var ToolNamesMigration = {
  search_file_content: ToolNames.GREP,
  // Legacy name from grep tool
  replace: ToolNames.EDIT,
  // Legacy name from edit tool
  task: ToolNames.AGENT
  // Legacy name from agent tool (renamed from task)
};
var ToolDisplayNamesMigration = {
  SearchFiles: ToolDisplayNames.GREP,
  // Old display name for Grep
  FindFiles: ToolDisplayNames.GLOB,
  // Old display name for Glob
  ReadFolder: ToolDisplayNames.LS,
  // Old display name for ListFiles
  Task: ToolDisplayNames.AGENT
  // Old display name for Agent (renamed from Task)
};

export {
  ToolNames,
  ToolDisplayNames,
  ToolNamesMigration,
  ToolDisplayNamesMigration
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
