// Force strict mode and setup for ESM
"use strict";
import {
  require_dist
} from "./chunk-ZERZSAZL.js";
import "./chunk-QN5NZ3UQ.js";
import "./chunk-BR4QREVK.js";
import "./chunk-A4BMJM77.js";
import "./chunk-J2S4EL5Y.js";
export default require_dist();
