// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-A4BMJM77.js";

// packages/core/src/config/models.ts
init_esbuild_shims();
var DEFAULT_QWEN_MODEL = "coder-model";
var DEFAULT_QWEN_FLASH_MODEL = "coder-model";
var DEFAULT_QWEN_EMBEDDING_MODEL = "text-embedding-v4";
var MAINLINE_CODER_MODEL = "qwen3.5-plus";

export {
  DEFAULT_QWEN_MODEL,
  DEFAULT_QWEN_FLASH_MODEL,
  DEFAULT_QWEN_EMBEDDING_MODEL,
  MAINLINE_CODER_MODEL
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
